summaryrefslogtreecommitdiff
path: root/src/frame.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/frame.h')
-rw-r--r--src/frame.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/src/frame.h b/src/frame.h
index 47970c3d6db..532e1f2b85b 100644
--- a/src/frame.h
+++ b/src/frame.h
@@ -124,7 +124,10 @@ struct frame
/* Predicate for selecting buffers for other-buffer. */
Lisp_Object buffer_predicate;
- /* Beyond here, there should be no more Lisp_Object components. */
+ /* List of buffers viewed in this frame, for other-buffer. */
+ Lisp_Object buffer_list;
+
+ /* beyond here, there should be no more Lisp_Object components. */
/* A buffer to hold the frame's name. We can't use the Lisp string's